"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.RCONPacket = void 0;
const bufwrapper_1 = require("@minecraft-js/bufwrapper");
const Int32LE_1 = require("../util/Int32LE");
class RCONPacket {
    /**
     * Read or write a packet
     * @param buf Buffer to create the packet from, can be `undefined` if you are building a packet
     */
    constructor(buf) {
        this.buf = buf || new bufwrapper_1.BufWrapper(null, { oneConcat: true });
    }
    /**
     * Write the data to the packet
     * @param type Type of the RCONPacket
     * @param payload Payload for this packet
     */
    write(type, payload) {
        this.type = type || this.type;
        this.payload = payload || this.payload;
        this.buf = new bufwrapper_1.BufWrapper(null, { oneConcat: true });
        this.buf.writeToBuffer((0, Int32LE_1.writeInt32LE)(this.type));
        this.buf.writeToBuffer(Buffer.from(this.payload, 'latin1'));
        // 1st null byte is for terminating the ascii text
        // 2nd null byte is the pad
        this.buf.writeBytes([0x00, 0x00]);
        this.buf.finish();
    }
    /**
     * Read the packet content
     */
    read(type) {
        this.type = type;
        let payloadLength = 0;
        while (true) {
            const byte = this.buf.readBytes(1)[0];
            if (byte === 0x00)
                break;
            payloadLength++;
        }
        const max = RCONPacket.MAX_SERVER_PAYLOAD_LENGTH;
        if (payloadLength > max)
            throw new Error(`[RCON] Maximum payload length is ${max} bytes, received ${payloadLength}`);
        const payloadOffset = 4 * 3;
        this.payload = this.buf.buffer
            .subarray(payloadOffset, payloadOffset + payloadLength)
            .toString('latin1');
        this.buf.readBytes(1);
        return this;
    }
}
exports.RCONPacket = RCONPacket;
/** Maximum client to server packet length */
RCONPacket.MAX_CLIENT_PAYLOAD_LENGTH = 1460;
/** Maximum server to client packet length */
RCONPacket.MAX_SERVER_PAYLOAD_LENGTH = 4110;
